👋 Welcome to XGrammar
======================

XGrammar is open-source solution for flexible, portable, and fast structured generations.
The mission of this project is to bring flexible zero-overhead structure generation everywhere.

.. toctree::
   :maxdepth: 1
   :caption: Get Started

   start/installation
   start/quick_start

.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   tutorials/constrained_decoding
   tutorials/workflow_of_xgrammar
   tutorials/advanced_topics
   tutorials/engine_integration
   tutorials/json_generation
   tutorials/ebnf_guided_generation

.. toctree::
   :maxdepth: 1
   :caption: XGrammar Features

   xgrammar_features/runtime_safeguards
   xgrammar_features/javascript_api

.. toctree::
   :maxdepth: 1
   :caption: Developer Guide

   developer_guide/building_docs
   developer_guide/code_coverage

.. toctree::
   :maxdepth: 1
   :caption: API Reference

   api/python/index


.. TODOs:
.. xgrammar_bnf
.. json_schema
.. supported_models
.. debugging
.. rewrite json/ebnf generation, engine_integration
